@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -150,6 +150,25 @@ class GrafeasAsyncClient:
     ) -> grafeas.Occurrence:
         r"""Gets the specified occurrence.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_get_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.GetOccurrenceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_occurrence(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.GetOccurrenceRequest, dict]):
                 The request object. Request to get an occurrence.
@@ -173,7 +192,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -231,6 +250,26 @@ class GrafeasAsyncClient:
     ) -> pagers.ListOccurrencesAsyncPager:
         r"""Lists occurrences for the specified project.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_list_occurrences():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.ListOccurrencesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_occurrences(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.ListOccurrencesRequest, dict]):
                 The request object. Request to list occurrences.
@@ -261,7 +300,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
@@ -328,6 +367,23 @@ class GrafeasAsyncClient:
         this method to delete an occurrence when the occurrence
         is no longer applicable for the given resource.
 
+
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_delete_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.DeleteOccurrenceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_occurrence(request=request)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.DeleteOccurrenceRequest, dict]):
                 The request object. Request to delete an occurrence.
@@ -345,7 +401,7 @@ class GrafeasAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -402,6 +458,25 @@ class GrafeasAsyncClient:
     ) -> grafeas.Occurrence:
         r"""Creates a new occurrence.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_create_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.CreateOccurrenceRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_occurrence(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.CreateOccurrenceRequest, dict]):
                 The request object. Request to create a new occurrence.
@@ -431,7 +506,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, occurrence])
         if request is not None and has_flattened_params:
@@ -481,6 +556,25 @@ class GrafeasAsyncClient:
     ) -> grafeas.BatchCreateOccurrencesResponse:
         r"""Creates new occurrences in batch.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_batch_create_occurrences():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.BatchCreateOccurrencesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.batch_create_occurrences(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.BatchCreateOccurrencesRequest, dict]):
                 The request object. Request to create occurrences in
@@ -513,7 +607,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, occurrences])
         if request is not None and has_flattened_params:
@@ -564,6 +658,25 @@ class GrafeasAsyncClient:
     ) -> grafeas.Occurrence:
         r"""Updates the specified occurrence.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_update_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.UpdateOccurrenceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.update_occurrence(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.UpdateOccurrenceRequest, dict]):
                 The request object. Request to update an occurrence.
@@ -597,7 +710,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, occurrence, update_mask])
         if request is not None and has_flattened_params:
@@ -650,6 +763,26 @@ class GrafeasAsyncClient:
         Consumer projects can use this method to get a note that
         belongs to a provider project.
 
+
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_get_occurrence_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.GetOccurrenceNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_occurrence_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.GetOccurrenceNoteRequest, dict]):
                 The request object. Request to get the note to which the
@@ -674,7 +807,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -731,6 +864,25 @@ class GrafeasAsyncClient:
     ) -> grafeas.Note:
         r"""Gets the specified note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_get_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.GetNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.GetNoteRequest, dict]):
                 The request object. Request to get a note.
@@ -754,7 +906,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -812,6 +964,26 @@ class GrafeasAsyncClient:
     ) -> pagers.ListNotesAsyncPager:
         r"""Lists notes for the specified project.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_list_notes():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.ListNotesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_notes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.ListNotesRequest, dict]):
                 The request object. Request to list notes.
@@ -842,7 +1014,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
@@ -907,6 +1079,22 @@ class GrafeasAsyncClient:
     ) -> None:
         r"""Deletes the specified note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_delete_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.DeleteNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_note(request=request)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.DeleteNoteRequest, dict]):
                 The request object. Request to delete a note.
@@ -924,7 +1112,7 @@ class GrafeasAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -982,6 +1170,26 @@ class GrafeasAsyncClient:
     ) -> grafeas.Note:
         r"""Creates a new note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_create_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.CreateNoteRequest(
+                    parent="parent_value",
+                    note_id="note_id_value",
+                )
+
+                # Make the request
+                response = client.create_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.CreateNoteRequest, dict]):
                 The request object. Request to create a new note.
@@ -1016,7 +1224,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, note_id, note])
         if request is not None and has_flattened_params:
@@ -1068,6 +1276,25 @@ class GrafeasAsyncClient:
     ) -> grafeas.BatchCreateNotesResponse:
         r"""Creates new notes in batch.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_batch_create_notes():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.BatchCreateNotesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.batch_create_notes(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.BatchCreateNotesRequest, dict]):
                 The request object. Request to create notes in batch.
@@ -1097,7 +1324,7 @@ class GrafeasAsyncClient:
                 Response for creating notes in batch.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, notes])
         if request is not None and has_flattened_params:
@@ -1149,6 +1376,25 @@ class GrafeasAsyncClient:
     ) -> grafeas.Note:
         r"""Updates the specified note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_update_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.UpdateNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.update_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.UpdateNoteRequest, dict]):
                 The request object. Request to update a note.
@@ -1182,7 +1428,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, note, update_mask])
         if request is not None and has_flattened_params:
@@ -1237,6 +1483,27 @@ class GrafeasAsyncClient:
         occurrences across consumer projects referencing the
         specified note.
 
+
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_list_note_occurrences():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.ListNoteOccurrencesRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_note_occurrences(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.ListNoteOccurrencesRequest, dict]):
                 The request object. Request to list occurrences for a
@@ -1269,7 +1536,7 @@ class GrafeasAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, filter])
         if request is not None and has_flattened_params:
