@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -287,6 +287,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.Occurrence:
         r"""Gets the specified occurrence.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_get_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.GetOccurrenceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_occurrence(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.GetOccurrenceRequest, dict]):
                 The request object. Request to get an occurrence.
@@ -310,7 +329,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -358,6 +377,26 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> pagers.ListOccurrencesPager:
         r"""Lists occurrences for the specified project.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_list_occurrences():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.ListOccurrencesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_occurrences(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.ListOccurrencesRequest, dict]):
                 The request object. Request to list occurrences.
@@ -388,7 +427,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
@@ -445,6 +484,23 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         this method to delete an occurrence when the occurrence
         is no longer applicable for the given resource.
 
+
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_delete_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.DeleteOccurrenceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_occurrence(request=request)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.DeleteOccurrenceRequest, dict]):
                 The request object. Request to delete an occurrence.
@@ -462,7 +518,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -509,6 +565,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.Occurrence:
         r"""Creates a new occurrence.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_create_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.CreateOccurrenceRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_occurrence(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.CreateOccurrenceRequest, dict]):
                 The request object. Request to create a new occurrence.
@@ -538,7 +613,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, occurrence])
         if request is not None and has_flattened_params:
@@ -588,6 +663,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.BatchCreateOccurrencesResponse:
         r"""Creates new occurrences in batch.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_batch_create_occurrences():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.BatchCreateOccurrencesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.batch_create_occurrences(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.BatchCreateOccurrencesRequest, dict]):
                 The request object. Request to create occurrences in
@@ -620,7 +714,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, occurrences])
         if request is not None and has_flattened_params:
@@ -671,6 +765,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.Occurrence:
         r"""Updates the specified occurrence.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_update_occurrence():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.UpdateOccurrenceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.update_occurrence(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.UpdateOccurrenceRequest, dict]):
                 The request object. Request to update an occurrence.
@@ -704,7 +817,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, occurrence, update_mask])
         if request is not None and has_flattened_params:
@@ -757,6 +870,26 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         Consumer projects can use this method to get a note that
         belongs to a provider project.
 
+
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_get_occurrence_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.GetOccurrenceNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_occurrence_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.GetOccurrenceNoteRequest, dict]):
                 The request object. Request to get the note to which the
@@ -781,7 +914,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -828,6 +961,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.Note:
         r"""Gets the specified note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_get_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.GetNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.GetNoteRequest, dict]):
                 The request object. Request to get a note.
@@ -851,7 +1003,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -899,6 +1051,26 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> pagers.ListNotesPager:
         r"""Lists notes for the specified project.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_list_notes():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.ListNotesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_notes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.ListNotesRequest, dict]):
                 The request object. Request to list notes.
@@ -929,7 +1101,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
@@ -984,6 +1156,22 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> None:
         r"""Deletes the specified note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_delete_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.DeleteNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_note(request=request)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.DeleteNoteRequest, dict]):
                 The request object. Request to delete a note.
@@ -1001,7 +1189,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1049,6 +1237,26 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.Note:
         r"""Creates a new note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_create_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.CreateNoteRequest(
+                    parent="parent_value",
+                    note_id="note_id_value",
+                )
+
+                # Make the request
+                response = client.create_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.CreateNoteRequest, dict]):
                 The request object. Request to create a new note.
@@ -1083,7 +1291,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, note_id, note])
         if request is not None and has_flattened_params:
@@ -1135,6 +1343,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.BatchCreateNotesResponse:
         r"""Creates new notes in batch.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_batch_create_notes():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.BatchCreateNotesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.batch_create_notes(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.BatchCreateNotesRequest, dict]):
                 The request object. Request to create notes in batch.
@@ -1164,7 +1391,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
                 Response for creating notes in batch.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, notes])
         if request is not None and has_flattened_params:
@@ -1215,6 +1442,25 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
     ) -> grafeas.Note:
         r"""Updates the specified note.
 
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_update_note():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.UpdateNoteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.update_note(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.UpdateNoteRequest, dict]):
                 The request object. Request to update a note.
@@ -1248,7 +1494,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, note, update_mask])
         if request is not None and has_flattened_params:
@@ -1303,6 +1549,27 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         occurrences across consumer projects referencing the
         specified note.
 
+
+        .. code-block:: python
+
+            from grafeas import grafeas_v1
+
+            def sample_list_note_occurrences():
+                # Create a client
+                client = grafeas_v1.GrafeasClient()
+
+                # Initialize request argument(s)
+                request = grafeas_v1.ListNoteOccurrencesRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_note_occurrences(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[grafeas.grafeas_v1.types.ListNoteOccurrencesRequest, dict]):
                 The request object. Request to list occurrences for a
@@ -1335,7 +1602,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, filter])
         if request is not None and has_flattened_params:
